/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'tt', {
	border: 'Frame чикләрен күрсәтү',
	noUrl: 'Please type the iframe URL', // MISSING
	scrolling: 'Enable scrollbars', // MISSING
	title: 'IFrame үзлекләре',
	toolbar: 'IFrame',
	tabindex: 'Remove from tabindex' // MISSING
} );
